/// <reference path="fourslash.ts" />

// @BaselineFile: getEmitOutputWithSemanticErrors.baseline

// @Filename: inputFile.ts
// @emitThisFile: true
//// var x:number = "hello world";

verify.baselineGetEmitOutput();